@@ -15,6 +15,7 @@ class SettingsProxy(object):
         self.default = self._get_settings_dict_from_module(
             default_settings_module)
         self.local = self._get_local_settings()
+        self.runtime = {}
 
     def _get_local_settings(self):
         dotdir = os.path.expanduser(u'~/.mopidy/')
@@ -37,6 +38,7 @@ class SettingsProxy(object):
     def current(self):
         current = copy(self.default)
         current.update(self.local)
+        current.update(self.runtime)
         return current
 
     def __getattr__(self, attr):
@@ -49,6 +51,12 @@ class SettingsProxy(object):
             raise SettingsError(u'Setting "%s" is empty.' % attr)
         return value
 
+    def __setattr__(self, attr, value):
+        if self._is_setting(attr):
+            self.runtime[attr] = value
+        else:
+            super(SettingsProxy, self).__setattr__(attr, value)
+
     def validate(self):
         if self.get_errors():
             logger.error(u'Settings validation errors: %s',
@@ -81,6 +89,8 @@ def validate_settings(defaults, settings):
     errors = {}
 
     changed = {
+        'DUMP_LOG_FILENAME': 'DEBUG_LOG_FILENAME',
+        'DUMP_LOG_FORMAT': 'DEBUG_LOG_FORMAT',
         'FRONTEND': 'FRONTENDS',
         'SERVER': None,
         'SERVER_HOSTNAME': 'MPD_SERVER_HOSTNAME',
@@ -122,7 +132,7 @@ def list_settings_optparse_callback(*args):
     lines = []
     for (key, value) in sorted(settings.current.iteritems()):
         default_value = settings.default.get(key)
-        if key.endswith('PASSWORD'):
+        if key.endswith('PASSWORD') and len(value):
             value = u'********'
         lines.append(u'%s:' % key)
         lines.append(u'  Value: %s' % repr(value))
