@@ -11,7 +11,7 @@ class VersionTest(unittest.TestCase):
         self.assert_(SV('0.1.0a0') < SV('0.1.0a1'))
         self.assert_(SV('0.1.0a1') < SV('0.1.0a2'))
         self.assert_(SV('0.1.0a2') < SV('0.1.0a3'))
-        self.assert_(SV('0.1.0a3') < SV(get_version()))
-        self.assert_(SV(get_version()) < SV('0.1.1'))
-        self.assert_(SV('0.1.1') < SV('0.2.0'))
+        self.assert_(SV('0.1.0a3') < SV('0.1.0'))
+        self.assert_(SV('0.1.0') < SV(get_version()))
+        self.assert_(SV(get_version()) < SV('0.2.1'))
         self.assert_(SV('0.2.0') < SV('1.0.0'))
